@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,8 @@ class QLineEdit;
 
 class QCheckBox;
 
-template<typename T> class QSharedPointer;
+template<typename T>
+class QSharedPointer;
 namespace PimCommon
 {
 class IncidencesForWidget;
@@ -45,7 +46,7 @@ public:
 protected:
     void init(const Akonadi::Collection &);
 
-private Q_SLOTS:
+private:
     void slotFolderContentsSelectionChanged(int);
     void slotNameChanged(const QString &name);
 
@@ -64,4 +65,3 @@ private:
 
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionGeneralPageFactory, CollectionGeneralPage)
 }
-
