@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONWITHCOMMAND_H
-#define MAILCOMMON_FILTERACTIONWITHCOMMAND_H
+#pragma once
 
 #include "filteractionwithurl.h"
 #include <QVector>
@@ -56,5 +55,3 @@ public:
     Q_REQUIRED_RESULT virtual ReturnCode genericProcess(ItemContext &context, bool filtering) const;
 };
 }
-
-#endif
